/*
 * Copyright CoreMedia AG, Hamburg, 2009. All rights reserved.
 */
package com.coremedia.jira.plugins.cloneandmove.issue.operations;

import com.atlassian.jira.issue.operations.CloneIssueOperation;
import com.atlassian.jira.issue.Issue;
import com.atlassian.jira.security.JiraAuthenticationContext;
import com.atlassian.jira.security.PermissionManager;
import com.atlassian.jira.security.Permissions;

import java.util.Map;
import java.util.HashMap;

/**
 * @author Mark Michaelis
 */
public class CloneAndMoveIssueOperation extends CloneIssueOperation {
  private final JiraAuthenticationContext authenticationContext;
  private final PermissionManager permissionManager;

  public CloneAndMoveIssueOperation(final JiraAuthenticationContext jiraAuthenticationContext,
                                    final PermissionManager permissionManager) {
    super(jiraAuthenticationContext, permissionManager);
    authenticationContext = jiraAuthenticationContext;
    this.permissionManager = permissionManager;
  }

  /**
   * Get the URL which should be opened when clicked on the given link.
   * @param issue the issue this links needs to be generated for
   * @return the (relative) URL to open when performing this operation
   */
  @Override
  public String getActionURL(final Issue issue) {
    return super.getActionURL(issue).replace("CloneIssueDetails", "CloneAndMoveIssueDetails");
  }

  /**
   * Get the HTML representation of the operation button
   * @param issue the issue to create the button for
   * @return HTML of the button to render
   */
  @Override
  public String getHtml(final Issue issue) {
    final Map<String, Object> params = new HashMap<String,  Object>();
    params.put("issue", issue);
    params.put("i18n", authenticationContext.getI18nHelper());
    params.put("actionUrl", getActionURL(issue));
    params.put("i18nDescKey", "issue.operations.cloneandmove");
    params.put("aId", "clone_and_move_issue");

    return getBullet() + descriptor.getHtml("view", params);
  }

  /**
   * This operation is only shown if the user has both permissions: To create an issue and to move it.
   * @param issue the issue to clone and move
   * @return true if the user might perform this action; false if not
   */
  @Override
  public boolean showOperation(final Issue issue) {
    return super.showOperation(issue) && permissionManager
            .hasPermission(Permissions.MOVE_ISSUE, issue, authenticationContext.getUser());
  }
}
